@@ -13,18 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from http import client as http_client
 import time
 from unittest import mock
 
-try:
-    import xml.etree.cElementTree as ET
-except ImportError:
-    import xml.etree.ElementTree as ET
-
 import ddt
+from defusedxml import ElementTree as etree
 from eventlet import greenthread
 from oslo_config import cfg
-import six
 
 from manila import exception
 from manila.share.drivers.qnap import api
@@ -81,8 +77,8 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
     def setUp(self):
         """Setup the Qnap Share Driver login TestCase."""
         super(QnapShareDriverLoginTestCase, self).setUp()
-        self.mock_object(six.moves.http_client, 'HTTPConnection')
-        self.mock_object(six.moves.http_client, 'HTTPSConnection')
+        self.mock_object(http_client, 'HTTPConnection')
+        self.mock_object(http_client, 'HTTPSConnection')
 
     @ddt.unpack
     @ddt.data({'mng_url': 'http://1.2.3.4:8080', 'port': '8080', 'ssl': False},
@@ -93,9 +89,9 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
         fake_get_basic_info_response_es = (
             fakes.FakeGetBasicInfoResponseEs_1_1_3())
         if ssl:
-            mock_connection = six.moves.http_client.HTTPSConnection
+            mock_connection = http_client.HTTPSConnection
         else:
-            mock_connection = six.moves.http_client.HTTPConnection
+            mock_connection = http_client.HTTPConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_get_basic_info_response_es,
@@ -128,7 +124,7 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
     def test_do_setup_positive_with_diff_nas(self, fake_basic_info):
         """Test do_setup with different NAS model."""
         fake_login_response = fakes.FakeLoginResponse()
-        mock_connection = six.moves.http_client.HTTPSConnection
+        mock_connection = http_client.HTTPSConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_basic_info,
@@ -173,7 +169,7 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
     def test_create_api_executor(self, fake_basic_info, expect_result):
         """Test do_setup with different NAS model."""
         fake_login_response = fakes.FakeLoginResponse()
-        mock_connection = six.moves.http_client.HTTPSConnection
+        mock_connection = http_client.HTTPSConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_basic_info,
@@ -206,7 +202,7 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
                                           fake_basic_info, expect_result):
         """Test do_setup with different NAS model."""
         fake_login_response = fakes.FakeLoginResponse()
-        mock_connection = six.moves.http_client.HTTPSConnection
+        mock_connection = http_client.HTTPSConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_basic_info,
@@ -225,7 +221,7 @@ class QnapShareDriverLoginTestCase(QnapShareDriverBaseTestCase):
         fake_login_response = fakes.FakeLoginResponse()
         fake_get_basic_info_response_error = (
             fakes.FakeGetBasicInfoResponseError())
-        mock_connection = six.moves.http_client.HTTPSConnection
+        mock_connection = http_client.HTTPSConnection
         mock_connection.return_value.getresponse.side_effect = [
             fake_login_response,
             fake_get_basic_info_response_error,
@@ -269,7 +265,7 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
 
     def get_share_info_return_value(self):
         """Return the share info form get_share_info method."""
-        root = ET.fromstring(fakes.FAKE_RES_DETAIL_DATA_SHARE_INFO)
+        root = etree.fromstring(fakes.FAKE_RES_DETAIL_DATA_SHARE_INFO)
 
         share_list = root.find('Volume_Info')
         share_info_tree = share_list.findall('row')
@@ -278,7 +274,7 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
 
     def get_snapshot_info_return_value(self):
         """Return the snapshot info form get_snapshot_info method."""
-        root = ET.fromstring(fakes.FAKE_RES_DETAIL_DATA_SNAPSHOT)
+        root = etree.fromstring(fakes.FAKE_RES_DETAIL_DATA_SNAPSHOT)
 
         snapshot_list = root.find('SnapshotList')
         snapshot_info_tree = snapshot_list.findall('row')
@@ -287,7 +283,7 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
 
     def get_specific_volinfo_return_value(self):
         """Return the volume info form get_specific_volinfo method."""
-        root = ET.fromstring(fakes.FAKE_RES_DETAIL_DATA_VOLUME_INFO)
+        root = etree.fromstring(fakes.FAKE_RES_DETAIL_DATA_VOLUME_INFO)
 
         volume_list = root.find('Volume_Info')
         volume_info_tree = volume_list.findall('row')
@@ -296,7 +292,7 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
 
     def get_specific_poolinfo_return_value(self):
         """Get specific pool info."""
-        root = ET.fromstring(fakes.FAKE_RES_DETAIL_DATA_SPECIFIC_POOL_INFO)
+        root = etree.fromstring(fakes.FAKE_RES_DETAIL_DATA_SPECIFIC_POOL_INFO)
 
         pool_list = root.find('Pool_Index')
         pool_info_tree = pool_list.findall('row')
@@ -305,7 +301,7 @@ class QnapShareDriverTestCase(QnapShareDriverBaseTestCase):
 
     def get_host_list_return_value(self):
         """Get host list."""
-        root = ET.fromstring(fakes.FAKE_RES_DETAIL_DATA_GET_HOST_LIST)
+        root = etree.fromstring(fakes.FAKE_RES_DETAIL_DATA_GET_HOST_LIST)
 
         hosts = []
         host_list = root.find('host_list')
